#include <string>

using namespace std;

string usr_merge(const string&);
